@@ -2,9 +2,18 @@ require File.dirname(__FILE__) + '/../spec_helper'
 
 describe Rack::Adapter do
   before do
+    @config_ru_path = File.dirname(__FILE__) + '/../../example'
     @rails_path = File.dirname(__FILE__) + '/../rails_app'
   end
   
+  it "should load Rack app from config" do
+    Rack::Adapter.load(@config_ru_path + '/config.ru').class.should == Proc
+  end
+  
+  it "should guess Rack app from dir" do
+    Rack::Adapter.guess(@config_ru_path).should == :rack
+  end
+  
   it "should guess rails app from dir" do
     Rack::Adapter.guess(@rails_path).should == :rails
   end
@@ -13,6 +22,10 @@ describe Rack::Adapter do
     proc { Rack::Adapter.guess('.') }.should raise_error(Rack::AdapterNotFound)
   end
   
+  it "should load Rack adapter" do
+    Rack::Adapter.for(:rack, :chdir => @config_ru_path).class.should == Proc
+  end
+  
   it "should load Rails adapter" do
     Rack::Adapter::Rails.should_receive(:new)
     Rack::Adapter.for(:rails, :chdir => @rails_path)
